@@ -27,7 +27,7 @@
 #include <mustache.hpp>
 #include "byte_range.h"
 #include "etag.h"
-#include "i18n.h"
+#include "i18n_utils.h"
 
 #include <zim/item.h>
 
@@ -145,6 +145,13 @@ protected: //data
   std::unique_ptr<Data> m_data;
 };
 
+struct NewHTTP404Response : ContentResponseBlueprint
+{
+  NewHTTP404Response(const RequestContext& request,
+                     const std::string& root,
+                     const std::string& urlPath);
+};
+
 struct HTTPErrorResponse : ContentResponseBlueprint
 {
   HTTPErrorResponse(const RequestContext& request,
@@ -173,9 +180,12 @@ struct HTTP400Response : HTTPErrorResponse
   explicit HTTP400Response(const RequestContext& request);
 };
 
-struct HTTP500Response : HTTPErrorResponse
+struct HTTP500Response : ContentResponseBlueprint
 {
-  explicit HTTP500Response(const RequestContext& request);
+  HTTP500Response(const RequestContext& request,
+                  const std::string& root,
+                  const std::string& urlPath,
+                  const std::string& error = "");
 };
 
 class ItemResponse : public Response {
@@ -190,6 +200,13 @@ class ItemResponse : public Response {
     std::string m_mimeType;
 };
 
+struct BlockExternalLinkResponse : ContentResponseBlueprint
+{
+  BlockExternalLinkResponse(const RequestContext& request,
+                            const std::string& root,
+                            const std::string& externalUrl);
+};
+
 }
 
 #endif //KIWIXLIB_SERVER_RESPONSE_H
