@@ -10,6 +10,8 @@ let viewerState = {
   uiLanguage: 'en',
 };
 
+const FULL_ROOT_URL = `${window.location.origin}${root}`;
+
 function dropUserLang(query) {
   const q = new URLSearchParams(query);
   q.delete('userlang');
@@ -92,7 +94,10 @@ function makeJSLink(jsCodeString, linkText, linkAttr="") {
   // in the JS code we have to URI-encode a second time.
   // (see https://stackoverflow.com/questions/33721510)
   const uriEncodedJSCode = encodeURIComponent(jsCodeString);
-  return `<a ${linkAttr} href="javascript:${uriEncodedJSCode}">${linkText}</a>`;
+  const linkPlainText = htmlDecode(linkText, "text/html");
+  linkAttr += ` href="javascript:${uriEncodedJSCode}"`;
+  linkAttr += ` title="${linkPlainText}"`;
+  return `<a ${linkAttr}>${linkText}</a>`;
 }
 
 function suggestionsApiURL()
@@ -259,29 +264,21 @@ function handle_location_hash_change() {
 }
 
 function translateErrorPageIfNeeded() {
-  const cw = contentIframe.contentWindow;
-  if ( cw.KIWIX_RESPONSE_TEMPLATE && cw.KIWIX_RESPONSE_DATA ) {
-    const template = htmlDecode(cw.KIWIX_RESPONSE_TEMPLATE);
-
-    // cw.KIWIX_RESPONSE_DATA belongs to the iframe context and running
-    // I18n.render() on it directly in the top context doesn't work correctly
-    // because the type checks (obj.__proto__ == ???.prototype) in
-    // I18n.instantiateParameterizedMessages() always fail (String.prototype
-    // refers to different objects in different contexts).
-    // Work arround that issue by copying the object into our context.
-    const params = JSON.parse(JSON.stringify(cw.KIWIX_RESPONSE_DATA));
-
-    const html = I18n.render(template, params);
-    const htmlDoc = new DOMParser().parseFromString(html, "text/html");
-    cw.document.documentElement.innerHTML = htmlDoc.documentElement.innerHTML;
-  }
+  translatePageInWindow(contentIframe.contentWindow);
 }
 
+
+let iframeLocationHref = null;
+
 function handle_content_url_change() {
+  if ( iframeLocationHref == contentIframe.contentWindow.location.href )
+    return;
+
   const iframeLocation = contentIframe.contentWindow.location;
+  iframeLocationHref = iframeLocation.href;
   console.log('handle_content_url_change: ' + iframeLocation.href);
   document.title = contentIframe.contentDocument.title;
-  const iframeContentUrl = iframeLocation.pathname;
+  const iframeContentUrl = iframeLocation.pathname + iframeLocation.hash;
   const iframeContentQuery = iframeLocation.search;
   const newHash = iframeUrl2UserUrl(iframeContentUrl, iframeContentQuery);
   history.replaceState(viewerState, null, makeURL(location.search, newHash));
@@ -342,20 +339,38 @@ function setHrefAvoidingWombatRewriting(target, url) {
   target._no_rewrite = old_no_rewrite;
 }
 
+function linkShouldBeOpenedInANewWindow(linkElement, mouseEvent) {
+  return linkElement.getAttribute("target") == "_blank"
+      || mouseEvent.ctrlKey
+      || mouseEvent.shiftKey
+      || mouseEvent.metaKey /* on Macs */;
+}
+
+function goingToOpenALinkToAnUndisplayableResource(url) {
+  return !navigator.pdfViewerEnabled && url.pathname.endsWith('.pdf');
+}
+
 function onClickEvent(e) {
   const iframeDocument = contentIframe.contentDocument;
   const target = matchingAncestorElement(e.target, iframeDocument, "a");
   if (target !== null && "href" in target) {
     const target_href = getRealHref(target);
     const target_url = new URL(target_href, iframeDocument.location);
+    if ( target_url.href.startsWith(`${FULL_ROOT_URL}/viewer#`) &&
+         !linkShouldBeOpenedInANewWindow(target, e) ) {
+      contentIframe.contentWindow.parent.location = target_url;
+      e.preventDefault();
+      return;
+    }
     const isExternalAppUrl = urlMustBeHandledByAnExternalApp(target_url);
-    if ( isExternalAppUrl && !viewerSettings.linkBlockingEnabled ) {
+    if ( (isExternalAppUrl && !viewerSettings.linkBlockingEnabled)
+         || goingToOpenALinkToAnUndisplayableResource(target_url) ) {
         target.setAttribute("target", "_blank");
     }
 
     if (isExternalAppUrl || isExternalUrl(target_href)) {
       const possiblyBlockedLink = blockLink(target_href);
-      if ( e.ctrlKey || e.shiftKey ) {
+      if ( linkShouldBeOpenedInANewWindow(target, e) ) {
         // The link will be loaded in a new tab/window - update the link
         // and let the browser handle the rest.
         setHrefAvoidingWombatRewriting(target, possiblyBlockedLink);
@@ -398,21 +413,34 @@ this.Element && function(ElementPrototype) {
     }
 }(Element.prototype);
 
-function setup_external_link_blocker() {
-  setupEventHandler(contentIframe.contentDocument, 'a', 'click', onClickEvent);
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // End of external link blocking
 ////////////////////////////////////////////////////////////////////////////////
 
+const internalUrlPrefix = `${FULL_ROOT_URL}/content/`;
+
+function setup_chaperon_mode() {
+  setupEventHandler(contentIframe.contentDocument, 'a', 'click', onClickEvent);
+  const links = contentIframe.contentDocument.getElementsByTagName('a');
+  for ( const a of links ) {
+    // XXX: wombat's possible involvement with href not taken into account
+    if ( a.hasAttribute('href') && a.href.startsWith(internalUrlPrefix) ) {
+      const userUrl = a.href.substr(internalUrlPrefix.length);
+      a.href = `${root}/viewer#${userUrl}`;
+    }
+  }
+}
+
 let viewerSetupComplete = false;
 
 function on_content_load() {
-  if ( viewerSetupComplete ) {
-    handle_content_url_change();
-  }
-  setup_external_link_blocker();
+  const loader = document.getElementById("kiwix__loader");
+
+  contentIframe.classList.remove("hidden");
+  loader.style.display = "none";
+  contentIframe.contentWindow.onhashchange = handle_content_url_change;
+  setInterval(handle_content_url_change, 100);
+  setup_chaperon_mode();
 }
 
 function htmlDecode(input) {
@@ -597,6 +625,12 @@ function updateUIText() {
 
   setTitle(document.getElementById("kiwix_serve_taskbar_random_button"),
            $t("random-page-button-text"));
+
+  // Add translation for loading text as soon as translations are available
+  const loadingTextElement = document.getElementById("kiwix__loading_text");
+  if (loadingTextElement) {
+    loadingTextElement.textContent = $t("text-loading-content");
+  }
 }
 
 function finishViewerSetupOnceTranslationsAreLoaded()
